SystemOrganization addCategory: #'Pastell-Tests'!
SystemOrganization addCategory: #'Pastell-Base'!

TestCase subclass: #PSTCollectionTest
	instanceVariableNames: 'collection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pastell-Tests'!

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
setUp
	collection := PastellCollection new! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testAdd
	| result |
	result := collection add: 12.
	self assert: collection size = 1.
	self assert: result = 12! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testAt
	collection add: 12.
	self assert: (collection at: 1)
			= 12! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testAtPut
	collection add: 12.
	collection at: 1 put: 12.
	self assert: (collection at: 1)
			= 12! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testChild
	| xml document html heads |
	xml := '<html><head/><head/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	html := document child: #html.
	heads := html child: #head.
	self assert: heads size = 2.
	self assert: heads first name = #head.
	self assert: heads last name = #head! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testContentString
	| xml document text |
	xml := '<html>value<head>Test</head></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	text := document html head contentString.
	self assert: text first = 'Test'.
	self assert: document html getContentAsString = 'value'! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testDNU
	| xml document html heads |
	xml := '<html><head/><head/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	html := document html.
	heads := html head.
	self assert: heads size = 2.
	self assert: heads first name = #head.
	self assert: heads last name = #head! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testDescendant
	| xml document html heads |
	xml := '<html><head/><head/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	html := document child: #html.
	heads := html descendant: #head.
	self assert: heads size = 2.
	self assert: heads first name = #head.
	self assert: heads last name = #head! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testDo
	| results result |
	collection add: 12.
	results := OrderedCollection new.
	result := collection
				do: [:each | results add: each].
	self assert: results size = 1.
	self assert: results first = 12.
	self assert: result = collection! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testNew
	self
		shouldnt: [PastellCollection new: 5]
		raise: Error! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testRemove
	| result |
	collection add: 12.
	result := collection
				remove: 12
				ifAbsent: [].
	self assert: collection size = 0.
	self assert: result = 12! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testRemoveAbsent
	| result |
	result := collection
				remove: 12
				ifAbsent: [42].
	self assert: result = 42! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testSlash
	| xml document html heads |
	xml := '<html><head/><head/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	html := document / #html.
	heads := html / #head.
	self assert: heads size = 2.
	self assert: heads first name = #head.
	self assert: heads last name = #head! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testSlashSlash
	| xml document html heads |
	xml := '<html><head/><head/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	html := document / #html.
	heads := html // #head.
	self assert: heads size = 2.
	self assert: heads first name = #head.
	self assert: heads last name = #head! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testSlashSlash2
	| xml document |
	xml := '<a><text>hello </text> <text>world</text></a>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	self assert: (document root // #text) getContentAsString = 'hello world'.
	xml := '<a><text>hello </text> <a><text>world</text></a></a>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	self assert: (document root // #text) getContentAsString = 'hello world'.
	xml := '<a><text>hello </text> <a><text>world</text></a></a>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream.
	self assert: (document root // #a / #text) getContentAsString = 'hello world'! !

!PSTCollectionTest methodsFor: 'as yet unclassified' stamp: ''!
testWithAll
	| coll |
	coll := OrderedCollection with: 12 with: 13.
	collection := PastellCollection withAll: coll.
	self assert: collection size = 2.
	self deny: collection == coll! !

TestCase subclass: #PSTXMLDocumentTest
	instanceVariableNames: 'collection xml document'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pastell-Tests'!

!PSTXMLDocumentTest methodsFor: 'as yet unclassified' stamp: ''!
setUp
	xml := '<html><head><title/></head><body/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream! !

!PSTXMLDocumentTest methodsFor: 'as yet unclassified' stamp: ''!
testDescendant
	| results |
	results := document descendant: #title.
	self assert: results size = 1.
	self assert: results first name = #title! !

!PSTXMLDocumentTest methodsFor: 'as yet unclassified' stamp: ''!
testRoot
	self assert: document root name = #html! !

TestCase subclass: #PSTXMLElementTest
	instanceVariableNames: 'xml document'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pastell-Tests'!

!PSTXMLElementTest methodsFor: 'as yet unclassified' stamp: ''!
setUp
	xml := '<html lang="it" foo="bar">value<head><title/></head><body/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream! !

!PSTXMLElementTest methodsFor: 'as yet unclassified' stamp: ''!
testAllAttributes
	self assert: document root attributes size = 2! !

!PSTXMLElementTest methodsFor: 'as yet unclassified' stamp: ''!
testAt
	self assert: (document root attributeAt: #lang)
			= 'it'! !

!PSTXMLElementTest methodsFor: 'as yet unclassified' stamp: ''!
testCommercialAt
	self assert: (document root attributeAt: #lang)
			= 'it'! !

TestCase subclass: #PSTXMLNodeWithElementsTest
	instanceVariableNames: 'collection xml document'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pastell-Tests'!

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
setUp
	xml := '<html><head><title/></head><body/></html>'.
	document := XMLDOMParser parseDocumentFrom: xml readStream! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testChild
	| results |
	results := document child: #html.
	self assert: results isCollection.
	self assert: results size = 1.
	self assert: results first name = #html! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testChildren
	| results |
	results := document root children.
	self assert: results size = 2.
	self assert: results first name = #head! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testDNU
	| results |
	results := document html.
	self assert: results isCollection.
	self assert: results size = 1.
	self assert: results first name = #html.
	self
		should: [document reset]
		raise: MessageNotUnderstood! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testDirectDescendant
	| results |
	results := document root descendant: #head.
	self assert: results size = 1.
	self assert: results first name = #head! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testSelfDescendant
	| results |
	results := document root descendant: #html.
	self assert: results first name = #html! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testSlash
	| results |
	results := document / #html.
	self assert: results isCollection.
	self assert: results size = 1.
	self assert: results first name = #html! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testSlashSlash
	| results |
	results := document // #title.
	self assert: results size = 1.
	self assert: results first name = #title! !

!PSTXMLNodeWithElementsTest methodsFor: 'as yet unclassified' stamp: ''!
testUndirectDescendant
	| results |
	results := document root descendant: #title.
	self assert: results size = 1.
	self assert: results first name = #title! !

OrderedCollection subclass: #PastellCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pastell-Base'!

!PastellCollection methodsFor: 'accessing' stamp: ''!
/ aSymbol 
	^ self child: aSymbol! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
// aSymbol 
	^ self descendant: aSymbol! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
child: aSymbol 
	| results |
	results := self species new.
	self
		do: [:each | results
				addAll: (each child: aSymbol)].
	^ results! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
contentString
	^ self
		collect: [:each | each contentString]! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
descendant: aSymbol 
	| results |
	results := self species new.
	self
		do: [:each | results
				addAll: (each descendant: aSymbol)].
	^ results! !

!PastellCollection methodsFor: 'error handling' stamp: ''!
doesNotUnderstand: aMessage 
	| v |
	v := self child: aMessage selector.
	^ v
		ifEmpty: [super doesNotUnderstand: aMessage]
		ifNotEmpty: [v]! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
getContentAsString
	| ans |
	ans := WriteStream on: String new.
	self contentString
		do: [:el | ans nextPutAll: el].
	^ ans contents! !

!PastellCollection methodsFor: 'accessing' stamp: ''!
getContentAsStringSeparatedBy: aCharacter 
	^ (self contentString
		inject: ''
		into: [:sum :el | sum , el , aCharacter asString]) allButLast! !

!XMLNodeWithElements methodsFor: '*Pastell-accessing' stamp: ''!
/ aSymbol 
	^ self child: aSymbol! !

!XMLNodeWithElements methodsFor: '*Pastell-accessing' stamp: ''!
// aSymbol 
	^ self descendant: aSymbol! !

!XMLNodeWithElements methodsFor: '*Pastell-accessing' stamp: ''!
child: aSymbol 
	| selected |
	selected := self elements
				select: [:each | each name = aSymbol].
	^ PastellCollection withAll: selected! !

!XMLNodeWithElements methodsFor: '*Pastell-accessing' stamp: ''!
children
	^ PastellCollection withAll: self elements! !

!XMLNodeWithElements methodsFor: '*Pastell-accessing' stamp: ''!
descendant: aSymbol 
	| selected |
	selected := PastellCollection new.
	self name = aSymbol
		ifTrue: [selected add: self].
	self elements
		ifNotEmpty: [selected
				addAll: ((PastellCollection withAll: self elements)
						descendant: aSymbol)].
	^ selected! !

!XMLNodeWithElements methodsFor: '*Pastell-error handing' stamp: ''!
doesNotUnderstand: aMessage 
	| v |
	v := self child: aMessage selector.
	^ v
		ifEmpty: [super doesNotUnderstand: aMessage]
		ifNotEmpty: [v]! !
